==> tdegraphics-R14.0.0-x86_64-ifx.txz: install/doinst.sh <==
( cd usr/share/doc/tde/HTML/en/kamera ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kamera ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcoloredit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcoloredit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kdvi ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kdvi ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kgamma ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kgamma ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kghostview ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kghostview ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kiconedit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kiconedit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kolourpaint ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kolourpaint ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kooka ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kooka ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kpdf ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kpdf ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kpovmodeler ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kpovmodeler ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kruler ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kruler ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ksnapshot ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ksnapshot ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kuickshow ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kuickshow ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kview ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kview ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/lib64 ; rm -rf libkfaximage.so.1 )
( cd usr/lib64 ; ln -sf libkfaximage.so.1.0.0 libkfaximage.so.1 )
( cd usr/lib64 ; rm -rf libkfaximage.so )
( cd usr/lib64 ; ln -sf libkfaximage.so.1 libkfaximage.so )
( cd usr/lib64 ; rm -rf libpoppler-tqt.so.0 )
( cd usr/lib64 ; ln -sf libpoppler-tqt.so.0.0.0 libpoppler-tqt.so.0 )
( cd usr/lib64 ; rm -rf libpoppler-tqt.so )
( cd usr/lib64 ; ln -sf libpoppler-tqt.so.0 libpoppler-tqt.so )
( cd usr/lib64 ; rm -rf libkghostviewlib.so.0 )
( cd usr/lib64 ; ln -sf libkghostviewlib.so.0.0.0 libkghostviewlib.so.0 )
( cd usr/lib64 ; rm -rf libkghostviewlib.so )
( cd usr/lib64 ; ln -sf libkghostviewlib.so.0 libkghostviewlib.so )
( cd usr/lib64 ; rm -rf libkpovmodeler.so.0 )
( cd usr/lib64 ; ln -sf libkpovmodeler.so.0.0.0 libkpovmodeler.so.0 )
( cd usr/lib64 ; rm -rf libkpovmodeler.so )
( cd usr/lib64 ; ln -sf libkpovmodeler.so.0 libkpovmodeler.so )
( cd usr/lib64 ; rm -rf libksvg.so.0 )
( cd usr/lib64 ; ln -sf libksvg.so.0.0.1 libksvg.so.0 )
( cd usr/lib64 ; rm -rf libksvg.so )
( cd usr/lib64 ; ln -sf libksvg.so.0 libksvg.so )
( cd usr/lib64 ; rm -rf libtext2path.so.0 )
( cd usr/lib64 ; ln -sf libtext2path.so.0.0.0 libtext2path.so.0 )
( cd usr/lib64 ; rm -rf libtext2path.so )
( cd usr/lib64 ; ln -sf libtext2path.so.0 libtext2path.so )
( cd usr/lib64 ; rm -rf libkimageviewer.so.0 )
( cd usr/lib64 ; ln -sf libkimageviewer.so.0.0.0 libkimageviewer.so.0 )
( cd usr/lib64 ; rm -rf libkimageviewer.so )
( cd usr/lib64 ; ln -sf libkimageviewer.so.0 libkimageviewer.so )
( cd usr/lib64 ; rm -rf libkmultipage.so.0 )
( cd usr/lib64 ; ln -sf libkmultipage.so.0.0.0 libkmultipage.so.0 )
( cd usr/lib64 ; rm -rf libkmultipage.so )
( cd usr/lib64 ; ln -sf libkmultipage.so.0 libkmultipage.so )
( cd usr/lib64 ; rm -rf libkscan.so.1 )
( cd usr/lib64 ; ln -sf libkscan.so.1.0.0 libkscan.so.1 )
( cd usr/lib64 ; rm -rf libkscan.so )
( cd usr/lib64 ; ln -sf libkscan.so.1 libkscan.so )

==> tdegraphics-14.0.11-x86_64-ifx.txz: install/doinst.sh <==

# Update the desktop database:
/usr/bin/update-desktop-database ./usr/share/applications

# Update hicolor theme cache:
/usr/bin/gtk-update-icon-cache -f -t ./usr/share/icons/hicolor

# Update the mime database:
/usr/bin/update-mime-database -Vn usr/share/mime

( cd usr/lib64 ; rm -rf libkfaximage.so )
( cd usr/lib64 ; ln -sf libkfaximage.so.1 libkfaximage.so )
( cd usr/lib64 ; rm -rf libkfaximage.so.1 )
( cd usr/lib64 ; ln -sf libkfaximage.so.1.0.0 libkfaximage.so.1 )
( cd usr/lib64 ; rm -rf libkghostviewlib.so )
( cd usr/lib64 ; ln -sf libkghostviewlib.so.0 libkghostviewlib.so )
( cd usr/lib64 ; rm -rf libkghostviewlib.so.0 )
( cd usr/lib64 ; ln -sf libkghostviewlib.so.0.0.0 libkghostviewlib.so.0 )
( cd usr/lib64 ; rm -rf libkimageviewer.so )
( cd usr/lib64 ; ln -sf libkimageviewer.so.0 libkimageviewer.so )
( cd usr/lib64 ; rm -rf libkimageviewer.so.0 )
( cd usr/lib64 ; ln -sf libkimageviewer.so.0.0.0 libkimageviewer.so.0 )
( cd usr/lib64 ; rm -rf libkpovmodeler.so )
( cd usr/lib64 ; ln -sf libkpovmodeler.so.0 libkpovmodeler.so )
( cd usr/lib64 ; rm -rf libkpovmodeler.so.0 )
( cd usr/lib64 ; ln -sf libkpovmodeler.so.0.0.0 libkpovmodeler.so.0 )
( cd usr/lib64 ; rm -rf libpoppler-tqt.so )
( cd usr/lib64 ; ln -sf libpoppler-tqt.so.0 libpoppler-tqt.so )
( cd usr/lib64 ; rm -rf libpoppler-tqt.so.0 )
( cd usr/lib64 ; ln -sf libpoppler-tqt.so.0.0.0 libpoppler-tqt.so.0 )
( cd usr/lib64 ; rm -rf libtdemultipage.so )
( cd usr/lib64 ; ln -sf libtdemultipage.so.0 libtdemultipage.so )
( cd usr/lib64 ; rm -rf libtdemultipage.so.0 )
( cd usr/lib64 ; ln -sf libtdemultipage.so.0.0.0 libtdemultipage.so.0 )
( cd usr/share/doc/tde/HTML/en/kamera ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kamera ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcoloredit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcoloredit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kdvi ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kdvi ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kfax ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kfax ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kfaxview ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kfaxview ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kgamma ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kgamma ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kghostview ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kghostview ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kolourpaint ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kolourpaint ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kooka ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kooka ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kpdf ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kpdf ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kpovmodeler ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kpovmodeler ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kruler ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kruler ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ksnapshot ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ksnapshot ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kuickshow ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kuickshow ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kview ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kview ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdeiconedit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdeiconedit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdeioslave/camera ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdeioslave/camera ; ln -sf /usr/share/doc/tde/HTML/en/common common )
